@@ -5,13 +5,13 @@ module Network.Wai.Middleware.AddHeaders
     ( addHeaders
     ) where
 
-import Network.HTTP.Types   (Header)
-import Network.Wai          (Middleware, modifyResponse, mapResponseHeaders)
-import Network.Wai.Internal (Response(..))
-import Data.ByteString      (ByteString)
-
-import qualified Data.CaseInsensitive as CI
 import Control.Arrow (first)
+import Data.ByteString (ByteString)
+import qualified Data.CaseInsensitive as CI
+import Network.HTTP.Types (Header)
+import Network.Wai (Middleware, mapResponseHeaders, modifyResponse)
+import Network.Wai.Internal (Response (..))
+
 
 addHeaders :: [(ByteString, ByteString)] -> Middleware
 -- ^ Prepend a list of headers without any checks
@@ -21,4 +21,4 @@ addHeaders :: [(ByteString, ByteString)] -> Middleware
 addHeaders h = modifyResponse $ addHeaders' (map (first CI.mk) h)
 
 addHeaders' :: [Header] -> Response -> Response
-addHeaders' h = mapResponseHeaders (\hs -> h ++ hs)
+addHeaders' h = mapResponseHeaders (h ++)
