@@ -1,12 +1,12 @@
 module Network.Wai.Test.Internal where
 
-import Network.Wai
-import qualified Control.Monad.Trans.State as ST
 import Control.Monad.Trans.Reader (ReaderT, runReaderT)
+import qualified Control.Monad.Trans.State as ST
+import Data.ByteString (ByteString)
 import Data.Map (Map)
 import qualified Data.Map as Map
+import Network.Wai (Application)
 import qualified Web.Cookie as Cookie
-import Data.ByteString (ByteString)
 
 type Session = ReaderT Application (ST.StateT ClientState IO)
 
@@ -15,7 +15,7 @@ type Session = ReaderT Application (ST.StateT ClientState IO)
 -- Since 3.0.6
 type ClientCookies = Map ByteString Cookie.SetCookie
 
-data ClientState = ClientState
+newtype ClientState = ClientState
     { clientCookies :: ClientCookies
     }
 
